<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

if ( ! function_exists( 'elead_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_is_headline_enable' ) ) :
	/**
	 * Check if headline is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_headline_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[headline_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_headline_content_post' ) ) :
	/**
	 * Check if headline content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_headline_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[headline_content_type]' )->value();
		if ( elead_pro_is_headline_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_headline_content_category' ) ) :
	/**
	 * Check if headline content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_headline_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[headline_content_type]' )->value();
		if ( elead_pro_is_headline_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_social_headline_enable' ) ) :
	/**
	 * Check if social headline is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_social_headline_enable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[headline_social_enable]' )->value();
		if ( elead_pro_is_headline_enable( $control ) &&  true === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_slider_enable' ) ) :
	/**
	 * Check if slider is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_slider_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[slider_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_slider_count' ) ) :
	/**
	 * Check if slider content is not demo or post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_slider_count( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'demo' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_slider_content_post' ) ) :
	/**
	 * Check if slider content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_slider_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;


if ( ! function_exists( 'elead_pro_slider_content_category' ) ) :
	/**
	 * Check if slider content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_slider_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_slider_content_page' ) ) :
	/**
	 * Check if slider content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_slider_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_slider_content_custom' ) ) :
	/**
	 * Check if slider content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_slider_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_demo_custom_disable' ) ) :
	/**
	 * Check if slider content is not demo and custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_demo_custom_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'demo' != $content_type && 'custom' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_demo_category_disable' ) ) :
	/**
	 * Check if slider content is not demo and category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_demo_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[slider_content_type]' )->value();
		if ( elead_pro_is_slider_enable( $control ) && 'demo' != $content_type && 'category' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_about_enable' ) ) :
	/**
	 * Check if about is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_about_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[about_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_about_content_page' ) ) :
	/**
	 * Check if about content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_about_content_post' ) ) :
	/**
	 * Check if about content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_about_content_custom' ) ) :
	/**
	 * Check if about content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_about_image_type_1' ) ) :
	/**
	 * Check if about content multiple image selected.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_image_type_1( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_about_image_type_2' ) ) :
	/**
	 * Check if about content multiple image selected.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_image_type_2( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		$about_image_type = $control->manager->get_setting( 'elead_pro_theme_options[about_image_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'custom' === $content_type && 'multiple-image' === $about_image_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_about_image_type_3' ) ) :
	/**
	 * Check if about content multiple image selected.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_about_image_type_3( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[about_content_type]' )->value();
		$about_image_type = $control->manager->get_setting( 'elead_pro_theme_options[about_image_type]' )->value();
		if ( elead_pro_is_about_enable( $control ) && 'custom' === $content_type && 'multiple-image' === $about_image_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_service_enable' ) ) :
	/**
	 * Check if service is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_service_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[service_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_services_content_category' ) ) :
	/**
	 * Check if services content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_services_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[service_content_type]' )->value();
		if ( elead_pro_is_service_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_services_content_post' ) ) :
	/**
	 * Check if services content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_services_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[service_content_type]' )->value();
		if ( elead_pro_is_service_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_services_content_page' ) ) :
	/**
	 * Check if services content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_services_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[service_content_type]' )->value();
		if ( elead_pro_is_service_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_services_content_custom' ) ) :
	/**
	 * Check if services content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_services_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[service_content_type]' )->value();
		if ( elead_pro_is_service_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_courses_enable' ) ) :
	/**
	 * Check if courses is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_courses_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[courses_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_count' ) ) :
	/**
	 * Check if courses content count is allowed for callback.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_count( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && ! in_array( $content_type, array( 'demo', 'post', 'course' ) ) )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_post' ) ) :
	/**
	 * Check if courses content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_category' ) ) :
	/**
	 * Check if courses content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_course' ) ) :
	/**
	 * Check if courses content is course.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_course( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'course' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_course_category' ) ) :
	/**
	 * Check if courses content is course category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_course_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'course-category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_custom' ) ) :
	/**
	 * Check if courses content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_courses_content_category_disable' ) ) :
	/**
	 * Check if is courses content type both category disable.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_courses_content_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[courses_content_type]' )->value();
		if ( elead_pro_is_courses_enable( $control ) && 'demo' != $content_type && 'category' != $content_type && 'course-category' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_call_to_action_enable' ) ) :
	/**
	 * Check if call to action is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_call_to_action_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[call_to_action_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_is_latest_news_enable' ) ) :
	/**
	 * Check if latest news & events is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_latest_news_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[latest_news_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_category' ) ) :
	/**
	 * Check if is latest news category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_latest_news_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[latest_news_content_type]' )->value();
		if ( elead_pro_is_latest_news_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_event_category' ) ) :
	/**
	 * Check if is latest news event category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_latest_news_content_event_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[latest_news_content_type]' )->value();
		if ( elead_pro_is_latest_news_enable( $control ) && 'event-category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_recent_event' ) ) :
	/**
	 * Check if is latest news recent events.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_latest_news_content_recent_event( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[latest_news_content_type]' )->value();
		if ( elead_pro_is_latest_news_enable( $control ) && 'recent-event' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_recent_post' ) ) :
	/**
	 * Check if is latest news recent posts.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_latest_news_content_recent_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[latest_news_content_type]' )->value();
		if ( elead_pro_is_latest_news_enable( $control ) && 'recent-post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_category_disable' ) ) :
	/**
	 * Check if is latest news content type both category disable.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_latest_news_content_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[latest_news_content_type]' )->value();
		if ( elead_pro_is_latest_news_enable( $control ) && 'demo' != $content_type && 'category' != $content_type && 'event-category' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_counter_enable' ) ) :
	/**
	 * Check if counter is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_counter_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[counter_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_is_team_enable' ) ) :
	/**
	 * Check if team is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_team_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[team_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_category' ) ) :
	/**
	 * Check if is team content type category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_post' ) ) :
	/**
	 * Check if is team content type post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_team_category' ) ) :
	/**
	 * Check if is team content type team category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_team_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'team-category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_team' ) ) :
	/**
	 * Check if is team content type team.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_team( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'team' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_custom' ) ) :
	/**
	 * Check if is team content type custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_team_content_category_disable' ) ) :
	/**
	 * Check if is team content type both category disable.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_team_content_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[team_content_type]' )->value();
		if ( elead_pro_is_team_enable( $control ) && 'demo' != $content_type && 'category' != $content_type && 'team-category' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_gallery_enable' ) ) :
	/**
	 * Check if gallery is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_gallery_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[gallery_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_gallery_content_post' ) ) :
	/**
	 * Check if is gallery content type post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_gallery_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[gallery_content_type]' )->value();
		if ( elead_pro_is_gallery_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_gallery_content_category' ) ) :
	/**
	 * Check if is gallery content type category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_gallery_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[gallery_content_type]' )->value();
		if ( elead_pro_is_gallery_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_gallery_content_custom' ) ) :
	/**
	 * Check if is gallery content type custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_gallery_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[gallery_content_type]' )->value();
		if ( elead_pro_is_gallery_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_testimonial_enable' ) ) :
	/**
	 * Check if testimonial is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_testimonial_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[testimonial_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_post' ) ) :
	/**
	 * Check if is testimonial content type post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_category' ) ) :
	/**
	 * Check if is testimonial content type category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_testimonial' ) ) :
	/**
	 * Check if is testimonial content type testimonial.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_testimonial( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'testimonial' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_recent' ) ) :
	/**
	 * Check if is testimonial content type recent.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_recent( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'recent-testimonial' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_count' ) ) :
	/**
	 * Check if testimonial content count is allowed for callback.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_count( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'demo' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_custom' ) ) :
	/**
	 * Check if testimonial content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_testimonial_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[testimonial_content_type]' )->value();
		if ( elead_pro_is_testimonial_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_subscribe_enable' ) ) :
	/**
	 * Check if subscribe is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_subscribe_enable( $control ) {
		if ( true == $control->manager->get_setting( 'elead_pro_theme_options[subscribe_enable]' )->value() && class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'subscriptions' ) )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_social_enable' ) ) :
	/**
	 * Check if social is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_social_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[social_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_is_contact_map_enable' ) ) :
	/**
	 * Check if contact map is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_contact_map_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[contact_map_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_contact_map_content_shortcode' ) ) :
	/**
	 * Check if is contact map content is shortcode.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_contact_map_content_shortcode( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[map_content_type]' )->value();
		if ( elead_pro_is_contact_map_enable( $control ) && 'shortcode' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_contact_map_content_embed' ) ) :
	/**
	 * Check if is contact map content is embed.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_contact_map_content_embed( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[map_content_type]' )->value();
		if ( elead_pro_is_contact_map_enable( $control ) && 'embed' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_gallery_template_category' ) ) :
	/**
	 * Check if is gallery type is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_gallery_template_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[gallery_template_type]' )->value();
		if ( 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_gallery_template_custom' ) ) :
	/**
	 * Check if is gallery type is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_gallery_template_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[gallery_template_type]' )->value();
		if ( 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

/* CUSTOM TEMPLATE */

if ( ! function_exists( 'elead_pro_is_abroad_study_destination_enable' ) ) :
	/**
	 * Check if study abroad destination is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_abroad_study_destination_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[destination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_count' ) ) :
	/**
	 * Check if is study abroad destination count is active.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_count( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) && in_array( $content_type, array( 'category', 'excursion-category', 'custom' ) ) )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_post' ) ) :
	/**
	 * Check if is study abroad destination content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) &&  'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_category' ) ) :
	/**
	 * Check if is study abroad destination content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) &&  'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_excursion' ) ) :
	/**
	 * Check if is study abroad destination content is excursion.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_excursion( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) &&  'excursion' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_excursion_category' ) ) :
	/**
	 * Check if is study abroad destination content is excursion category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_excursion_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) &&  'excursion-category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_abroad_destination_custom' ) ) :
	/**
	 * Check if is study abroad destination content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_abroad_destination_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) &&  'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_destination_content_category_disable' ) ) :
	/**
	 * Check if is destination content type both category disable.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_destination_content_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[destination_content_type]' )->value();
		if ( elead_pro_is_abroad_study_destination_enable( $control ) && in_array( $content_type, array( 'custom', 'post', 'excursion' ) ) )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_abroad_study_guide_enable' ) ) :
	/**
	 * Check if study abroad guide is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_abroad_study_guide_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[study_guide_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_study_guide_content_post' ) ) :
	/**
	 * Check if is study guide content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_guide_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[study_guide_content_type]' )->value();
		if ( elead_pro_is_abroad_study_guide_enable( $control ) &&  'post' === $content_type )
			return true;
		else
			return false;
	}
endif;


if ( ! function_exists( 'elead_pro_study_guide_content_category' ) ) :
	/**
	 * Check if is study guide content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_guide_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[study_guide_content_type]' )->value();
		if ( elead_pro_is_abroad_study_guide_enable( $control ) &&  'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_guide_content_not_post' ) ) :
	/**
	 * Check if is study guide content is not post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_guide_content_not_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[study_guide_content_type]' )->value();
		if ( elead_pro_is_abroad_study_guide_enable( $control ) &&  'post' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_study_guide_content_custom' ) ) :
	/**
	 * Check if is study guide content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_study_guide_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[study_guide_content_type]' )->value();
		if ( elead_pro_is_abroad_study_guide_enable( $control ) &&  'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_goal_section_enable' ) ) :
	/**
	 * Check if goal service is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_goal_section_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[goal_section_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_service_goal_content_post' ) ) :
	/**
	 * Check if is service goal content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_service_goal_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[goal_content_type]' )->value();
		if ( elead_pro_is_goal_section_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_service_goal_content_page' ) ) :
	/**
	 * Check if is service goal content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_service_goal_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[goal_content_type]' )->value();
		if ( elead_pro_is_goal_section_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_service_goal_content_custom' ) ) :
	/**
	 * Check if is service goal content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_service_goal_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[goal_content_type]' )->value();
		if ( elead_pro_is_goal_section_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_core_service_enable' ) ) :
	/**
	 * Check if core service is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_core_service_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[core_service_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_core_service_content_page' ) ) :
	/**
	 * Check if is core service content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_core_service_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[core_service_content_type]' )->value();
		if ( elead_pro_is_core_service_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_core_service_content_custom' ) ) :
	/**
	 * Check if is core service content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_core_service_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[core_service_content_type]' )->value();
		if ( elead_pro_is_core_service_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_core_service_content_post' ) ) :
	/**
	 * Check if is core service content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_core_service_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[core_service_content_type]' )->value();
		if ( elead_pro_is_core_service_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_quality_service_enable' ) ) :
	/**
	 * Check if quality service is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_quality_service_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[quality_service_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_quality_service_content_post' ) ) :
	/**
	 * Check if is quality service content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_quality_service_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[quality_service_content_type]' )->value();
		if ( elead_pro_is_quality_service_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_quality_service_content_category' ) ) :
	/**
	 * Check if is quality service content is category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_quality_service_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[quality_service_content_type]' )->value();
		if ( elead_pro_is_quality_service_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_quality_service_content_custom' ) ) :
	/**
	 * Check if is quality service content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_quality_service_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[quality_service_content_type]' )->value();
		if ( elead_pro_is_quality_service_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_quality_service_content_not_post' ) ) :
	/**
	 * Check if is quality service content is not post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_quality_service_content_not_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[quality_service_content_type]' )->value();
		if ( elead_pro_is_quality_service_enable( $control ) && 'post' != $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_message_enable' ) ) :
	/**
	 * Check if about us message is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_message_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[message_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_message_content_custom' ) ) :
	/**
	 * Check if is message content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_message_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[message_content_type]' )->value();
		if ( elead_pro_is_message_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_message_content_post' ) ) :
	/**
	 * Check if is message content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_message_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[message_content_type]' )->value();
		if ( elead_pro_is_message_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_message_content_page' ) ) :
	/**
	 * Check if is message content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_message_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[message_content_type]' )->value();
		if ( elead_pro_is_message_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_features_enable' ) ) :
	/**
	 * Check if about us features is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_features_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[features_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_features_content_page' ) ) :
	/**
	 * Check if is features content is page.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_features_content_page( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[features_content_type]' )->value();
		if ( elead_pro_is_features_enable( $control ) && 'page' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_features_content_post' ) ) :
	/**
	 * Check if is features content is post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_features_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[features_content_type]' )->value();
		if ( elead_pro_is_features_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_features_content_custom' ) ) :
	/**
	 * Check if is features content is custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_features_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[features_content_type]' )->value();
		if ( elead_pro_is_features_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_is_aboutteam_enable' ) ) :
	/**
	 * Check if aboutteam is enabled.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_is_aboutteam_enable( $control ) {
		return $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_enable]' )->value();
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_category' ) ) :
	/**
	 * Check if is aboutteam content type category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_post' ) ) :
	/**
	 * Check if is aboutteam content type post.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_post( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'post' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_team_category' ) ) :
	/**
	 * Check if is aboutteam content type category.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_team_category( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'team-category' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_team' ) ) :
	/**
	 * Check if is aboutteam content type team.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_team( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'team' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_custom' ) ) :
	/**
	 * Check if is aboutteam content type custom.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_custom( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'custom' === $content_type )
			return true;
		else
			return false;
	}
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_category_disable' ) ) :
	/**
	 * Check if is aboutteam content type both category disable.
	 *
	 * @since Elead Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function elead_pro_aboutteam_content_category_disable( $control ) {
		$content_type = $control->manager->get_setting( 'elead_pro_theme_options[aboutteam_content_type]' )->value();
		if ( elead_pro_is_aboutteam_enable( $control ) && 'demo' != $content_type && 'category' != $content_type && 'team-category' != $content_type )
			return true;
		else
			return false;
	}
endif;