<?php
/**
 * Courses Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_courses', array(
	'title'             => esc_html__( 'Courses','elead-pro' ),
	'description'       => esc_html__( 'Courses Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// courses Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['courses_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_enable]', array(
	'label'            	=> esc_html__( 'Enable Courses Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_courses',
	'type'             	=> 'checkbox',
) );

// courses Section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['courses_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_courses',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_courses_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[courses_title]', array(
		'selector'            => '#our-courses .wrapper .entry-header h2.entry-title',
		'settings'            => 'elead_pro_theme_options[courses_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_courses_title',
    ) );
}


// courses Section subtitle setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_sub_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['courses_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_sub_title]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_courses',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_courses_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[courses_sub_title]', array(
		'selector'            => '#our-courses .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'elead_pro_theme_options[courses_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_courses_subtitle',
    ) );
}

// courses Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_content_type]', array(
	'default'          	=> $options['courses_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_content_type]', array(
	'label'            	=> esc_html__( 'Courses Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_courses',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_courses_enable',
	'choices'			=> elead_pro_courses_content_type(),
) );

// Add courses count setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[no_of_courses]', array(
	'default'           => $options['no_of_courses'],
	'sanitize_callback' => 'elead_pro_sanitize_number_range',
	'validate_callback' => 'elead_pro_validate_course_count',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[no_of_courses]', array(
	'label'           	=> esc_html__( 'Number of Courses', 'elead-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'elead-pro' ),
	'section'         	=> 'elead_pro_courses',
	'type'            	=> 'number',
	'active_callback' 	=> 'elead_pro_courses_content_count',
	'input_attrs'     	=> array(
		'max' 	=> 6,
		'min' 	=> 3,
		'style' => 'width:100px'
	)
) );

// courses Section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_content_post]', array(
	'active_callback'	=> 'elead_pro_courses_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_courses',
	'type'				=> 'text',
) );

// courses Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[courses_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[courses_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_courses',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_courses_content_category',
) ) );

// courses Section content type course setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_content_course]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_content_course]', array(
	'active_callback'	=> 'elead_pro_courses_content_course',
	'label'             => esc_html__( 'Input Courses Post Ids', 'elead-pro' ),
	'description'       => esc_html__( 'Simply hover post title on dashboard to see the Post ID. Max no. of posts allowed is 6. ie: 11, 24, 34', 'elead-pro' ),
	'section'           => 'elead_pro_courses',
	'type'				=> 'text',
) );

// courses Section content type course category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[courses_content_course_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[courses_content_course_category]', array(
	'label'           => esc_html__( 'Select Course Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_courses',
	'taxonomy'		  => 'tp-course-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_courses_content_course_category',
) ) );


for ( $i = 1; $i <= $options['no_of_courses']; $i++ ) {
	// Courses custom post hr setting and control
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[courses_custom_hr_line_'.$i.']',
		array(
			'section'         => 'elead_pro_courses',
			'active_callback' => 'elead_pro_courses_content_custom',
			'type'			  => 'hr'
	) ) );

	// Courses custom note
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_note_'.$i.']', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[courses_custom_note_'.$i.']', array(
		'label'           	=> sprintf( esc_html__( 'Input Custom Value For Course %s ', 'elead-pro' ),$i ),
		'section'         	=> 'elead_pro_courses',
		'type'            	=> 'description',
		'active_callback' 	=> 'elead_pro_courses_content_custom',
	) ) );

	// Courses Section custom title setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => esc_html__( 'Painting & Sketch', 'elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[courses_custom_title_'.$i.']', array(
		'active_callback'	=> 'elead_pro_courses_content_custom',
		'label'             => sprintf( esc_html__( 'Course Name %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_courses',
		'type'				=> 'text'
	) );

	// Courses Section custom price setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_price_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => esc_html__( '$300', 'elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[courses_custom_price_'.$i.']', array(
		'active_callback'	=> 'elead_pro_courses_content_custom',
		'label'             => sprintf( esc_html__( 'Course Price %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_courses',
		'type'				=> 'text'
	) );

	// Courses Section custom title link setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_title_custom_url_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => esc_html__( '#', 'elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[courses_title_custom_url_'.$i.']', array(
		'active_callback'	=> 'elead_pro_courses_content_custom',
		'label'             => sprintf( esc_html__( 'Course Title Link %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_courses',
		'type'				=> 'text'
	) );


	// Courses Section custom excerpt setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_excerpt_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
		'default'           => esc_html__( 'Interdum et malesuada fames ac ante ipsum primis in faucibus. Fusce male sua da ante sed rhoncus blandit', 'elead-pro' ),
	) );

	$wp_customize->add_control( 'elead_pro_theme_options[courses_custom_excerpt_'.$i.']', array(
		'active_callback'	=> 'elead_pro_courses_content_custom',
		'label'             => sprintf( esc_html__( 'Course Excerpt %s', 'elead-pro' ),$i ),
		'section'           => 'elead_pro_courses',
		'type'				=> 'textarea'
	) );

	// Courses Section custom background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_image_'.$i.']', array(
		'sanitize_callback' => 'elead_pro_sanitize_image',
		'default'           => get_template_directory_uri() . '/assets/uploads/courses-01.jpg',
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[courses_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Course Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 400, 400 ),
			'section'     		=> 'elead_pro_courses',
			'active_callback'	=> 'elead_pro_courses_content_custom',
	) ) );
	
}

// Courses Section button label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_btn_label]', array(
	'default'           => $options['courses_custom_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_custom_btn_label]', array(
	'active_callback'	=> 'elead_pro_courses_content_category_disable',
	'label'             => esc_html__( 'Custom button label', 'elead-pro' ),
	'section'           => 'elead_pro_courses',
	'type'				=> 'text'
) );

// Courses Section button label url setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[courses_custom_btn_url]', array(
	'default'           => $options['courses_custom_btn_url'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[courses_custom_btn_url]', array(
	'active_callback'	=> 'elead_pro_courses_content_category_disable',
	'label'             => esc_html__( 'Custom button url', 'elead-pro' ),
	'section'           => 'elead_pro_courses',
	'type'				=> 'text'
) );