<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
$options = elead_pro_get_theme_options();
$blog_title     = ! empty( $options['blog_section_title'] ) ? $options['blog_section_title'] : '';
$blog_subtitle  = ! empty( $options['blog_section_subtitle'] ) ? $options['blog_section_subtitle'] : '';
get_header(); ?>
	<div class="wrapper page-section">
		<?php if( ! empty( $blog_title ) || ! empty( $blog_subtitle ) ) : ?>
            <header class="page-header align-center">
                <?php if ( ! empty( $blog_title ) ) : ?>
                    <h2 class="section-title"><?php echo esc_html( $blog_title ); ?></h2>
                <?php endif; 
                if ( ! empty( $blog_subtitle ) ) : ?>
                    <p class="entry-title-desc"><?php echo esc_html( $blog_subtitle ); ?></p>
                <?php endif; ?>
            </header><!-- .entry-header -->
        <?php endif; ?>     
	    <div class="page-decoration">
	        <img src="<?php echo get_template_directory_uri() . '/assets/uploads/decoration.png'; ?>" alt="<?php esc_attr_e( 'Decoration','elead-pro' ); ?>">
	    </div>

		<div id="primary" class="content-area">
            <main id="main" class="site-main" role="main">
                <div id="archive-blog-wrapper" class="archive-blog-wrapper clear col-3">

					<?php
					if ( have_posts() ) :

						$i = 1;
						/* Start the Loop */
						while ( have_posts() ) : the_post();
							/**
							 * elead_pro_blog_content_action hook
							 *
							 * @hooked elead_pro_blog_content -  10
							 *
							 */
							do_action( 'elead_pro_blog_content_action', $i );
							$i++;
						endwhile;


					else :

						get_template_part( 'template-parts/content', 'none' );

					endif; ?>
				</div><!-- .archive-blog-wrapper -->
				<?php
				/**
				* Hook - elead_pro_action_pagination.
				*
				* @hooked elead_pro_pagination 
				*/
				do_action( 'elead_pro_action_pagination' ); 

				/**
				* Hook - elead_pro_infinite_loader_spinner_action.
				*
				* @hooked elead_pro_infinite_loader_spinner 
				*/
				do_action( 'elead_pro_infinite_loader_spinner_action' );
				
				?>

			</main><!-- #main -->
		</div><!-- #primary -->
	</div><!-- .wrapper -->

<?php
get_footer();
